package com.fs.company.constant;

import lombok.Getter;

/**
 * 支付状态枚举类
 *
 * 描述支付过程中可能的状态
 */
@Getter
public enum PaymentStatus {

    /**
     * 支付创建，初始状态
     */
    CREATED(0, "创建"),

    /**
     * 支付处理中
     */
    PROCESSING(1, "处理中"),

    /**
     * 支付成功
     */
    SUCCESS(2, "支付成功"),

    /**
     * 支付失败
     */
    FAILED(3, "支付失败");

    /**
     * 状态码
     * -- GETTER --
     *  获取状态码
     *
     * @return 状态码

     */
    private final int code;

    /**
     * 状态描述
     * -- GETTER --
     *  获取状态描述
     *
     * @return 状态描述

     */
    private final String description;

    /**
     * 构造函数
     *
     * @param code 状态码
     * @param description 状态描述
     */
    PaymentStatus(int code, String description) {
        this.code = code;
        this.description = description;
    }

    /**
     * 根据状态码获取对应的枚举值
     *
     * @param code 状态码
     * @return 对应的支付状态枚举，如果没找到则返回null
     */
    public static PaymentStatus getByCode(int code) {
        for (PaymentStatus status : PaymentStatus.values()) {
            if (status.getCode() == code) {
                return status;
            }
        }
        return null;
    }

    @Override
    public String toString() {
        return code + ":" + description;
    }
}
